<?php

namespace Stripe\Exception\OAuth;

/**
 * UnsupportedResponseTypeException is thrown when an unsupported response type
 * parameter is specified.
 */
class UnsupportedResponseTypeException extends OAuthErrorException
{
}
